import { random, sample, times } from 'lodash'
import nouns from './nouns'
import adjs from './adjectives'

class Generator {
    
    /**
     * Generate random project name.
     * 
     * @param {object} options 
     * @return {array}
     */
    generate(options) {
        let defaults = { words: 2, number: false, alliterative: false }
        options = Object.assign(defaults, options)

        let raw = this.getRawProjName(options)
        
        this.projName = {
            raw,
            spaced: raw.join(' '),
            dashed: raw.join('-')
        }

        return this
    } 

    /**
     * Get random project name.
     * 
     * @param {object} options 
     * @return {array}
     */
    getRawProjName(options) {
        let raw = [];

        times(options.words - 1, function () {
            raw.push(sample(adjs).toLowerCase())
        })
        raw.push(sample(nouns).toLowerCase())
        if (options.number) {
            raw.push(random(1, 9999))
        }

        return raw
    }

    /**
     * Get dashed project name.
     */
    dashed() {
        return this.projName.dashed
    }

    /**
     * Get spaced project name.
     */
    spaced() {
        return this.projName.spaced
    }

    /**
     * Get raw project name.
     */
    raw() {
        return this.projName.raw
    }
}

let generator = new Generator()
export default generator